@@ -37,7 +37,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION );
 BEGIN {
-    $VERSION = '0.06';
+    $VERSION = '0.07';
 }
 
 # Ours
@@ -162,6 +162,10 @@ sub tickSnapshotEnd
     return;
 }
 
+# IB API >= v9.66
+sub marketDataType
+{}
+
 #
 # Orders
 #
@@ -205,6 +209,9 @@ sub execDetails
 {}
 sub execDetailsEnd
 {}
+# IB API >= 9.67
+sub commissionReport
+{}
 
 #
 # Market Depth
